## Version:0.1.1 -- 21 Mar 2025

*  Supports plugin installation through the Conductor Companion App.

## Version:0.1.0 -- 15 Jan 2025

*  Ensure Unreal render engine compatability by only displaying single GPU instance types